@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +19,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('chart_format13.xlsx')
+        self.set_filename("chart_format13.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with chart formatting."""
@@ -26,7 +27,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'line'})
+        chart = workbook.add_chart({"type": "line"})
 
         chart.axis_ids = [51785088, 51804032]
 
@@ -34,25 +35,28 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
             [1, 2, 3, 4, 5],
             [2, 4, 6, 8, 10],
             [3, 6, 9, 12, 15],
-
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
-        worksheet.write_column('C1', data[2])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
+        worksheet.write_column("C1", data[2])
 
-        chart.add_series({
-            'categories': '=Sheet1!$A$1:$A$5',
-            'values': '=Sheet1!$B$1:$B$5',
-            'data_labels': {'value': 1},
-        })
+        chart.add_series(
+            {
+                "categories": "=Sheet1!$A$1:$A$5",
+                "values": "=Sheet1!$B$1:$B$5",
+                "data_labels": {"value": 1},
+            }
+        )
 
-        chart.add_series({
-            'categories': '=Sheet1!$A$1:$A$5',
-            'values': '=Sheet1!$C$1:$C$5',
-        })
+        chart.add_series(
+            {
+                "categories": "=Sheet1!$A$1:$A$5",
+                "values": "=Sheet1!$C$1:$C$5",
+            }
+        )
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
