@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +19,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('escapes06.xlsx')
+        self.set_filename("escapes06.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file a num format that require XML escaping."""
@@ -26,11 +27,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        num_format = workbook.add_format({'num_format': '[Red]0.0%\\ "a"'})
+        num_format = workbook.add_format({"num_format": '[Red]0.0%\\ "a"'})
 
-        worksheet.set_column('A:A', 14)
+        worksheet.set_column("A:A", 14)
 
-        worksheet.write('A1', 123, num_format)
+        worksheet.write("A1", 123, num_format)
 
         workbook.close()
 
