@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,10 +19,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("header_image13.xlsx")
 
-        self.set_filename('header_image13.xlsx')
-
-        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
+        self.ignore_elements = {
+            "xl/worksheets/sheet1.xml": ["<pageMargins", "<pageSetup"]
+        }
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -29,11 +32,14 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.set_header('&L&G&C&G&R&G',
-                             {'image_left': self.image_dir + 'black_72.jpg',
-                              'image_center': self.image_dir + 'black_150.jpg',
-                              'image_right': self.image_dir + 'black_300.jpg',
-                              })
+        worksheet.set_header(
+            "&L&G&C&G&R&G",
+            {
+                "image_left": self.image_dir + "black_72.jpg",
+                "image_center": self.image_dir + "black_150.jpg",
+                "image_right": self.image_dir + "black_300.jpg",
+            },
+        )
 
         workbook.close()
 
