@@ -18,7 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-        self.set_filename("utf8_09.xlsx")
+        self.set_filename("utf8_01.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with utf-8 strings."""
@@ -26,9 +26,8 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        num_format = workbook.add_format({"num_format": "[$¥-411]#,##0.00"})
 
-        worksheet.write("A1", 1, num_format)
+        worksheet.write("A1", "Это фраза на русском!")
 
         workbook.close()
 
