@@ -10,7 +10,8 @@
 import unittest
 from io import StringIO
 
-from ...styles import Styles
+from xlsxwriter.color import Color
+from xlsxwriter.styles import Styles
 
 
 class TestWriteMruColors(unittest.TestCase):
@@ -27,7 +28,9 @@ class TestWriteMruColors(unittest.TestCase):
     def test_write_mru_colors(self):
         """Test the _write_mru_colors() method"""
 
-        self.styles._write_mru_colors(["FF26DA55", "FF792DC8", "FF646462"])
+        self.styles._write_mru_colors(
+            [Color("26DA55"), Color("792DC8"), Color("646462")]
+        )
 
         exp = """<mruColors><color rgb="FF646462"/><color rgb="FF792DC8"/><color rgb="FF26DA55"/></mruColors>"""
         got = self.fh.getvalue()
